@@ -1,4 +1,3 @@
-# Lint as: python3
 # Copyright 2018 Verily Life Sciences Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -91,6 +90,9 @@ _ZONES = [
     'asia-south1-a',
     'asia-south1-b',
     'asia-south1-c',
+    'asia-south2-a',
+    'asia-south2-b',
+    'asia-south2-c',
     'asia-southeast1-a',
     'asia-southeast1-b',
     'asia-southeast1-c',
@@ -100,6 +102,12 @@ _ZONES = [
     'australia-southeast1-a',
     'australia-southeast1-b',
     'australia-southeast1-c',
+    'australia-southeast2-a',
+    'australia-southeast2-b',
+    'australia-southeast2-c',
+    'europe-central2-a',
+    'europe-central2-b',
+    'europe-central2-c',
     'europe-north1-a',
     'europe-north1-b',
     'europe-north1-c',
@@ -121,6 +129,9 @@ _ZONES = [
     'northamerica-northeast1-a',
     'northamerica-northeast1-b',
     'northamerica-northeast1-c',
+    'northamerica-northeast2-a',
+    'northamerica-northeast2-b',
+    'northamerica-northeast2-c',
     'southamerica-east1-a',
     'southamerica-east1-b',
     'southamerica-east1-c',
